## XYZRequest

### Modules that make the API easy to get	简单API爬虫获取

#### Notice:The lastest version is 2022.1	注意：最新版本2022.1

##### 1.Download	下载

pip install xyzrequest==2022.1

##### 2. Import Package	导入

import xyzrequest

##### 4. Function	函数

​	(1)youdao_translate_AUTO( string )

​		NetEase Youdao Dictionary translation, automatic language detection

​		网易有道词典，自动检测语言翻译

​	(2)baidu_OCR( apiKey , secretKey , imagePath )

​		Baidu image text recognition OCR

​		百度图片文字识别OCR

​		ApiKey and secretKey, Watch the website https://cloud.baidu.com/doc/OCR/index.html, log in and get the keys

​		ApiKey和secretKey，详细请见https://cloud.baidu.com/doc/OCR/index.html，登录并获取密钥
